pub struct KvCacheContract {
pub k: Shape,
pub v: Shape,
}Expand description
KV cache tensor shapes exposed by attention blocks (associated type stand-in).
Fields
k: Shapev: ShapeTrait Implementations
Sourceimpl Clone for KvCacheContract
impl Clone for KvCacheContract
Sourcefn clone(&self) -> KvCacheContract
fn clone(&self) -> KvCacheContract
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KvCacheContract
impl Debug for KvCacheContract
Sourceimpl PartialEq for KvCacheContract
impl PartialEq for KvCacheContract
Sourcefn eq(&self, other: &KvCacheContract) -> bool
fn eq(&self, other: &KvCacheContract) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for KvCacheContract
impl StructuralPartialEq for KvCacheContract